@@ -7,10 +7,13 @@ OC.L10N.register(
     "Activity feed" : "דיווחי פעילות",
     "Your settings have been updated." : "ההגדרות שלך עודכנו",
     "Settings have been updated." : "ההגדרות עודכנו",
+    "remote user" : "משתמש מרוחק",
     "Recent activity" : "פעילות אחרונה",
     "No activities" : "אין פעילויות",
     "More activities" : "פעילויות נוספות",
     "Daily activity summary for %s" : "סיכום פעילות יומית עבור %s",
+    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "אתה יכול לבטל את תמצית האימיילים <a href=\"%s\">בהגדרות</a>.",
+    "You can disable daily digest emails in the settings: %s" : "אתה יכול לבטל את תמצית האימיילים היומית בהגדרות: %s",
     "All activities" : "כל הפעילויות",
     "By others" : "על ידי אחרים",
     "By you" : "על ידך",
@@ -19,6 +22,8 @@ OC.L10N.register(
     "Hello %s," : "שלום %s,",
     "There was some activity at %s" : "הייתה פעילות ב%s",
     "_and %n more _::_and %n more _" : ["ו־%n נוסף","ו־%n נוספים","ו־%n נוספים"],
+    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "אתה יכול לשנות את תדירות של האימיילים האלו או לבטל אותם<a href=\"%s\">בהגדרות</a>.",
+    "You can change the frequency of these emails or disable them in the settings: %s" : "אתה יכול לשנות או לבטל את התדירות של האימיילים האלה בהגדרות: %s",
     "Mail" : "דואר",
     "Push" : "דחיפה",
     "Activity" : "פעילות",
