@@ -15,6 +15,9 @@ OC.L10N.register(
     "Tags" : "태그",
     "Places" : "장소",
     "Map" : "지도",
+    "This name is already in use." : "이 이름은 이미 사용 중입니다.",
+    "\"{char}\" is not allowed inside a filename." : "파일 이름에 \"{char}\"(을)를 사용할 수 없습니다.",
+    "Invalid filename." : "잘못된 파일 이름",
     "Name of the album" : "앨범의 이름",
     "Location of the album" : "앨범의 위치",
     "Back" : "뒤로",
@@ -31,7 +34,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "앨범을 수정할 수 있는 사람 및 그룹 추가",
     "Search people or groups" : "사람 및 그룹 검색",
     "No recommendations. Start typing." : "추천 없음. 타이핑을 시작하십시오",
-    "Remove {collaboratorLabel} from the collaborators list" : "공동 작업자 목록에서 {collaboratorLabel} 제거",
     "Copy the public link" : "공개 링크 복사",
     "Public link copied!" : "공개 링크 복사!",
     "Copy public link" : "공개 링크 복사",
@@ -44,7 +46,7 @@ OC.L10N.register(
     "All folders" : "모든 폴더",
     "Add folder" : "폴더 추가",
     "Home" : "집",
-    "View" : "보기",
+    "General" : "일반",
     "Unselect all" : "모두 선택 해제",
     "Edit album details" : "앨범 세부 정보 수정",
     "Delete album" : "앨범 삭제",
@@ -53,10 +55,17 @@ OC.L10N.register(
     "Merge with different person" : "다른 사람에게 병합",
     "Remove from favorites" : "즐겨찾기에서 제거",
     "Remove person" : "사람 제거",
+    "Loading folders…" : "폴더 불러오는 중…",
     "Add to album" : "앨범에 추가",
     "Delete selection" : "선택 항목 삭제",
     "Unassigned faces" : "지정되지 않은 얼굴",
+    "Last week" : "저번 주",
     "Details" : "세부사항",
+    "Cancel" : "취소",
+    "Confirm" : "확인",
+    "Group" : "구룹",
+    "Remove {collaboratorLabel} from the collaborators list" : "공동 작업자 목록에서 {collaboratorLabel} 제거",
+    "View" : "보기",
     "Add" : "추가"
 },
 "nplurals=1; plural=0;");
