@@ -32,20 +32,16 @@ OC.L10N.register(
     "Ordered list" : "Gesorteerde lys",
     "Blockquote" : "Blokaanhaling",
     "Cancel" : "Cancel",
+    "Save" : "Stoor",
     "to" : "aan",
-    "Upload" : "Oplaai",
     "Edit" : "Wysig",
+    "Upload" : "Oplaai",
     "Headings" : "Koppe",
     "Heading 2" : "Kop 2",
     "Heading 3" : "Kop 3",
     "Heading 4" : "Kop 4",
     "Heading 5" : "Kop 5",
     "Details" : "Besonderhede",
-    "Choose" : "Kies",
-    "Use current version" : "Gebruik huidige weergawe",
-    "Use the saved version" : "Gebruik die bewaarde weergawe",
-    "Info" : "Inligting",
-    "Success" : "Sukses",
-    "Warning" : "Waarskuwing"
+    "Choose" : "Kies"
 },
 "nplurals=2; plural=(n != 1);");
