@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "نوع الملف غير معروف",
     "An error occurred. Please contact your admin." : "حدث خطأ، يرجى مراجعة المسؤول.",
     "Invalid image" : "الصورة غير صالحة",
-    "No temporary profile picture available, try again" : "لا تتوفر صورة ملف شخصي مؤقتة، حاول مرة أخرى",
-    "No crop data provided" : "لم يتم تحديد قص البيانات.",
-    "No valid crop data provided" : "تحديد قص البيانات غير صحيح.",
-    "Crop is not square" : "القص ليس مربعا",
     "State token does not match" : "حالة Token غير مطابقة",
     "Invalid app password" : "كلمة المرور للتطبيق غير صحيحه",
     "Could not complete login" : "لا يمكن إكمال عملية تسجيل الدخول",
@@ -51,6 +47,11 @@ OC.L10N.register(
     "No translation provider available" : "لا توجد خدمة للترجمة",
     "Could not detect language" : "لم يُمكن اكتشاف اللغة",
     "Unable to translate" : "لم يُمكن الترجمة",
+    "[%d / %d]: %s" : "[%d/%d]: %s",
+    "Repair step:" : "خطوة صيانة:",
+    "Repair info:" : "معلومات صيانة:",
+    "Repair warning:" : "تحذير صيانة:",
+    "Repair error:" : "خطأ صيانة:",
     "Nextcloud Server" : "خادم نكست كلاود",
     "Some of your link shares have been removed" : "تم ازالة البعض من مشاركة الروابط الخاصة بك.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "نظرا لسبب آمني تم ازالة البعض من روابط المشاركة الخاصة بك. يرجى مراجعة الرابط التالي لمزيد من التفاصيل.",
@@ -58,11 +59,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "أدخِل مفتاح الاشتراك الخاص بك في تطبيق الدعم لزيادة حد الأقصى من الحسابات. يمنحك هذا أيضًا جميع المزايا الإضافية التي يقدمها Nextcloud Enterprise ويوصى به بشدة للشركات و المؤسسات.",
     "Learn more ↗" : "تعلم المزيد ↗",
     "Preparing update" : "جارٍ تهيئة التحديث",
-    "[%d / %d]: %s" : "[%d/%d]: %s",
-    "Repair step:" : "خطوة صيانة:",
-    "Repair info:" : "معلومات صيانة:",
-    "Repair warning:" : "تحذير صيانة:",
-    "Repair error:" : "خطأ صيانة:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "يرجى الترقية من خلال سطر الأوامر command line updater حيث أن الترقية من المستعرض معطلة في ملف config.php.",
     "Turned on maintenance mode" : "تشغيل وضع الصيانة.",
     "Turned off maintenance mode" : "تعطيل وضع الصيانة.",
@@ -79,16 +75,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (غير متوافق)",
     "The following apps have been disabled: %s" : "التطبيقات التاليه غير مفعله: %s",
     "Already up to date" : "محدّثة مسبقاً",
-    "Error occurred while checking server setup" : "تم العثور على خطأ  اثناء فحص إعدادات الخادم",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "للمزيد من التفاصيل، يرجى الإطلاع على {linkstart} الدليل ↗{linkend}.",
-    "unknown text" : "النص غير معروف",
-    "Hello world!" : "مرحبا بالعالم!",
-    "sunny" : "مشمس",
-    "Hello {name}, the weather is {weather}" : "مرحبًا {name}، حالة الطقس {weather}",
-    "Hello {name}" : "مرحبا {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>هذه هي نتائج البحث الخاصة بك <script>تنبيه(1)</script> </strong>",
-    "new" : "جديد",
-    "_download %n file_::_download %n files_" : ["تنزيل %n ملف","تنزيل ملف واحد","تنزيل ملفين","تنزيل %n ملفات","تنزيل %n ملفات","تنزيل %n ملفات"],
+    "Unknown" : "غير معروف",
+    "PNG image" : "صورة PNG",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "جاري التحديث، وقد يؤدي مغادرة هذه الصفحة إلى توقف العملية في بعض الاحيان.",
     "Update to {version}" : "التحديث إلى {version}",
     "An error occurred." : "حدث خطأ.",
@@ -97,19 +85,21 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "فشل التحديث. يرجى التبليغ عن هذه المشكلة إلى <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\"> مجتمع Nextcloud </a>.",
     "Continue to {productName}" : "أكمل إلى {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال%n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني.","تم التحديث بنجاح، سوف يعاد توجيهك إلى {productName} خلال %n ثواني."],
+    "Done" : "تمّ",
     "Applications menu" : "قائمة التطبيقات",
     "Apps" : "التطبيقات",
     "More apps" : "المزيد من التطبيقات",
     "_{count} notification_::_{count} notifications_" : ["{count} إخطارات","{count} إخطارات","{count} إخطارات","{count} إخطارات","{count} إخطارات","{count} إخطارات"],
     "No" : "لا",
     "Yes" : "نعم",
+    "App password" : "كلمة مرور التطبيق",
+    "Grant access" : "السماح بالنفاذ",
     "The remote URL must include the user." : "عنوان URL  القَصِي يجب أن يحتوي على المستخدِم.",
     "Invalid remote URL." : "عنوان URL البعيد غير صحيح.",
     "Failed to add the public link to your Nextcloud" : "فشل في إضافة الرابط العام إلى الخادم السحابي الخاص بك",
     "Federated user" : "مستخدم السحابة الموحدة",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "إنشاء مشاركة",
-    "Direct link copied to clipboard" : "تمّ نسخ الرابط المباشر إلى الحافظة",
     "Please copy the link manually:" : "يرجى نسخ الرابط يدوياً:",
     "Custom date range" : "نطاق زمني مخصص",
     "Pick start date" : "إختر تاريخ البدء",
@@ -118,7 +108,6 @@ OC.L10N.register(
     "Search in current app" : "البحث في التطبيق الحالي",
     "Clear search" : "مَحوُ البحث",
     "Search everywhere" : "البحث الشامل",
-    "Searching …" : "يتم الآن البحث…",
     "Start typing to search" : "اكتب هنا للبحث",
     "No matching results" : "لا توجد نتائج مطابقة",
     "Today" : "اليوم",
@@ -137,17 +126,15 @@ OC.L10N.register(
     "Load more results" : " عرض المزيد من النتائج",
     "Search in" : "بحث في",
     "Log in" : "تسجيل الدخول",
-    "Logging in …" : "تسجيل الدخول …",
     "Log in to {productName}" : "تسجيل الدخول إلى {productName}",
     "Wrong login or password." : "معرف الدخول أو كلمة مرور خاطئة.",
     "This account is disabled" : "هذا الحساب معطل",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "لقد اكتشفنا عدة محاولات تسجيل دخول غير صالحة من عنوان IP الخاص بك. لذلك تم تقييد تسجيل الدخول التالي الخاص بك حتى 30 ثانية.",
     "Account name or email" : "اسم الحساب أو البريد الالكتروني",
     "Account name" : "اسم الحساب",
     "Server side authentication failed!" : "رفض الخادم المصادقة!",
     "Please contact your administrator." : "يرجى التواصل مع مسؤول النظام.",
-    "Temporary error" : "خطأ مؤقت",
-    "Please try again." : "يرجى المحاولة مرة أخرى.",
+    "Session error" : "خطأ في الجلسة",
+    "It appears your session token has expired, please refresh the page and try again." : "يبدو أن أَمَارَة جلستك قد انتهت صلاحيتها. رجاءً، حدِّث الصفحة ثم حاول مرة أخرى.",
     "An internal error occurred." : "حدث خطأ داخلي.",
     "Please try again or contact your administrator." : "حاول مجددا أو تواصل مع مسؤول النظام.",
     "Password" : "كلمة المرور",
@@ -174,21 +161,23 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "مستندات و جداول و عروض تعاونية، بناءً على تطبيق كولابورا Collabora Online.",
     "Distraction free note taking app." : "تطبيق تسجيل الملاحظات دون تشتيت",
     "Recommended apps" : "التطبيقات المستحسنة",
-    "Loading apps …" : "تحميل التطبيقات…",
     "Could not fetch list of apps from the App Store." : "لا يمكن العثور على قائمة التطبيقات من متجر التطبيقات.",
     "App download or installation failed" : "فشل تحميل أو تثبيت التطبيق ",
     "Cannot install this app because it is not compatible" : "لا يمكن تثبيت هذا التطبيق لانه غير متوافق",
     "Cannot install this app" : "لا يمكن تثبيت هذا التطبيق",
     "Skip" : "تخطي",
-    "Installing apps …" : "جاري تثبيت التطبيقات…",
     "Install recommended apps" : "ثبت التطبيقات الاضافيه",
+    "Online" : "مُتّصلٌ",
+    "Away" : "بالخارج",
+    "Busy" : "مشغول",
+    "Do not disturb" : "الرجاء عدم الإزعاج",
+    "Mute all notifications" : "عدم إظهار جميع التنبيهات",
+    "Invisible" : "مخفي",
+    "Appear offline" : "الحالة غير متصل",
     "Avatar of {displayName}" : "صورة الملف الشخصي الرمزية لـ {displayName}",
     "Settings menu" : "قائمة الإعدادات",
-    "Loading your contacts …" : "تحميل جهات الإتصال",
-    "Looking for {term} …" : "جاري البحث عن {term}",
     "Search contacts" : "بحث جهات الاتصال",
     "Reset search" : "إعادة تعيين البحث",
-    "Search contacts …" : "البحث عن جهات الإتصال",
     "Could not load your contacts" : "تعذر تحميل جهات الإتصال",
     "No contacts found" : "لم يعثر على جهات اتصال",
     "Show all contacts" : "إظهار كافة جهات الإتصال",
@@ -200,13 +189,29 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "حدث خطأ أثناء البحث عن {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "يبدأ البحث بمجرد أن تبدأ الكتابة. و يمكنك الوصول إلى النتيجة بمفاتيح الأسهم",
     "Search for {name} only" : "البحث عن {name} فقط",
-    "Loading more results …" : "جاري عرض المزيد من النتائج…",
     "Forgot password?" : "هل نسيت كلمة السر ؟",
     "Back to login form" : "عودة إلى نموذج الدخول",
     "Back" : "العودة",
     "Login form is disabled." : "نموذج تسجيل الدخول معطل",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "نموذج تسجيل الدخول إلى نكست كلاود مُعطّل. استخدم خيار تسجيل دخول آخر إذا كان متاحًا أو اتصل بمسؤول النظام.",
+    "Connect to your account" : "الاتصال بحسابك",
+    "Security warning" : "تحذير الأمان",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "إذا كنت لا تحاول تعيين جهاز أو تطبيق جديد ، فإن شخصًا ما يحاول خداعك لمنحه حق الوصول إلى بياناتك. في هذه الحالة ، لا تقم بالمتابعة وبدلاً من ذلك اتصل بمسؤول النظام.",
+    "Alternative log in using app password" : "تسجيل الدخول بطريقة بديلة باستخدام كلمة مرور التطبيق",
+    "Account connected" : "الحساب متصل",
+    "Your client should now be connected!" : "من المفترض ان عميلك متصل الان!",
+    "You can close this window." : "بإمكانك اغلاق النافذة",
+    "Account access" : "حساب النفاذ",
     "More actions" : "إجراءات إضافية",
+    "This share is password-protected" : "هذه المشاركة محمية بكلمة مرور",
+    "The password is wrong or expired. Please try again or request a new one." : "كلمة المرور أمّا غير مُطابقة أو منتهية الصلاحية. رجاءً حاول مرة أخرى أو أطلب واحدة جديدة.",
+    "Submit" : "إرسال ",
+    "Please type in your email address to request a temporary password" : "رجاءً أدخل عنوان بريدك الالكتروني لطلب كلمة مرور مؤقتة",
+    "Password sent!" : "تم إرسال كلمة المرور!",
+    "You are not authorized to request a password for this share" : "لست مخولاً لطلب كلمة مرور لهذه المشاركة",
+    "Email address" : "عنوان البريد الإلكتروني",
+    "Request password" : "طلب كلمة المرور",
+    "Forgot password" : "نسيت الكلمة السرية",
     "Password is too weak" : "كلمة المرور ضعيفة جدّاً",
     "Password is weak" : "كلمة المرور ضعيفة",
     "Password is average" : "كلمة المرور متوسطة القوة",
@@ -218,7 +223,6 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "لمعلومات أكثر حول كيفية تهيئة خادومك، رجاءً،{linkStart}أنظُر التوثيق {linkEnd}",
     "Autoconfig file detected" : "تمّ اكتشاف ملف التهيئة التلقائية Autoconfig",
     "The setup form below is pre-filled with the values from the config file." : "نموذج الإعدادات أدناه تمّت تعبئته بقيم من ملف التهيئة.",
-    "Security warning" : "تحذير الأمان",
     "Create administration account" : "إنشاء حساب إدارة",
     "Administration account name" : "اسم حساب الإدارة",
     "Administration account password" : "كلمة مرور حساب الإدارة",
@@ -239,7 +243,6 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "يرجى تحديد رقم المنفذ مع اسم المضيف (على سبيل المثال ، mycloud:5432).",
     "Database host" : "خادم قاعدة البيانات",
     "localhost" : "localhost جهازك المُضِيف المحلي",
-    "Installing …" : "جاري التثبيت...",
     "Install" : "تثبيت",
     "Need help?" : "تحتاج إلى مساعدة؟",
     "See the documentation" : "اطلع على التعليمات",
@@ -248,7 +251,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "المستعرض غير مدعوم. رجاءً قم بالترقية إلى نسخة أحدث أو إلى  مستعرض آخر مدعوم.",
     "Continue with this unsupported browser" : "إستمر مع هذا المستعرض غير المدعوم",
     "Supported versions" : "النسخ المدعومة",
-    "Search {types} …" : "بحث {types} …",
     "Choose {file}" : "إختر {file}",
     "Choose" : "اختيار",
     "Copy to {target}" : "أُنسُخ إلى {target}",
@@ -268,7 +270,10 @@ OC.L10N.register(
     "(all selected)" : "(إختيار الكل)",
     "({count} selected)" : "({count} تم تحديد)",
     "Error loading file exists template" : "خطأ في تحميل القالب الحالي",
-    "Saving …" : "جاري الحفظ…",
+    "Saving …" : "حفظ ...",
+    "Groups" : "المجموعات",
+    "Group list is empty" : "قائمة المجموعة فارغة",
+    "Unable to retrieve the group list" : "تعذر استرداد قائمة المجموعة",
     "seconds ago" : "منذ ثواني",
     "Connection to server lost" : "تم فقد الاتصال بالخادم",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثانية","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني ","حدث خطأ أثناء تحميل الصفحة، سيعاد التحميل خلال %n ثواني."],
@@ -283,26 +288,17 @@ OC.L10N.register(
     "Type to search for existing projects" : "اكتب هنا للبحث عن مشاريع مسجلة",
     "New in" : "الجديد في",
     "View changelog" : "اعرض سجل التغييرات",
-    "No action available" : "لا يتوفر أي إجراء",
-    "Error fetching contact actions" : "حدث خطأ أثناء جلب إجراءات جهات الاتصال",
     "Close \"{dialogTitle}\" dialog" : "أغلق الحوار \"{dialogTitle}\"",
     "Email length is at max (255)" : "طول رسالة الإيميل وصل أقصى المسموح ( 255)",
-    "Non-existing tag #{tag}" : "وسم غير موجود #{tag}",
-    "Restricted" : "مقيد",
-    "Invisible" : "مخفي",
-    "Delete" : "إلغاء",
-    "Rename" : "إعادة التسمية",
-    "Collaborative tags" : "أوسمة تعاونية",
-    "No tags found" : "لم يُعثَر على أي وسم",
     "Clipboard not available, please copy manually" : "الحافظة غير متاحة. رجاءً، قم بالنسخ يدويّاً",
     "Personal" : "شخصي",
     "Accounts" : "الحسابات",
     "Admin" : "المدير",
     "Help" : "المساعدة",
     "Access forbidden" : "الوصول محظور",
+    "Back to %s" : "العودة إلى %s",
     "Page not found" : "الصفحة غير موجودة",
     "The page could not be found on the server or you may not be allowed to view it." : "لم يُمكن إيجاد الصفحة على الخادم أو ربما غير مسموح لك بالوصول إليها.",
-    "Back to %s" : "العودة إلى %s",
     "Too many requests" : "الطلبات أقصى من الحد المسموح",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "يوجد طلبات أقصى من الحد المسموح به في الشبكة. أعد المحاولة أو اتصل بمسؤول النظام.",
     "Error" : "خطأ",
@@ -327,25 +323,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "تجاهل التنقل في التطبيق",
     "Go to %s" : "الإنتقال إلى %s",
     "Get your own free account" : "احصل على حساب لك بالمجان",
-    "Connect to your account" : "الاتصال بحسابك",
-    "Please log in before granting %1$s access to your %2$s account." : "يرجى تسجيل الدخول قبل الحصول على اذن %1$s في حسابك %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "إذا كنت لا تحاول تعيين جهاز أو تطبيق جديد ، فإن شخصًا ما يحاول خداعك لمنحه حق الوصول إلى بياناتك. في هذه الحالة ، لا تقم بالمتابعة وبدلاً من ذلك اتصل بمسؤول النظام.",
-    "App password" : "كلمة مرور التطبيق",
-    "Grant access" : "السماح بالنفاذ",
-    "Alternative log in using app password" : "تسجيل الدخول بطريقة بديلة باستخدام كلمة مرور التطبيق",
-    "Account access" : "حساب النفاذ",
-    "Currently logged in as %1$s (%2$s)." : "مسجّل حاليّاً كـ %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "انت على وشك الحصول على اذن %1$s لحسابك %2$s.",
-    "Account connected" : "الحساب متصل",
-    "Your client should now be connected!" : "من المفترض ان عميلك متصل الان!",
-    "You can close this window." : "بإمكانك اغلاق النافذة",
     "Previous" : "السابق",
-    "This share is password-protected" : "هذه المشاركة محمية بكلمة مرور",
-    "The password is wrong or expired. Please try again or request a new one." : "كلمة المرور أمّا غير مُطابقة أو منتهية الصلاحية. رجاءً حاول مرة أخرى أو أطلب واحدة جديدة.",
-    "Please type in your email address to request a temporary password" : "رجاءً أدخل عنوان بريدك الالكتروني لطلب كلمة مرور مؤقتة",
-    "Email address" : "عنوان البريد الإلكتروني",
-    "Password sent!" : "تم إرسال كلمة المرور!",
-    "You are not authorized to request a password for this share" : "لست مخولاً لطلب كلمة مرور لهذه المشاركة",
     "Two-factor authentication" : "المصادقة بخطوتين",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "تعزيز الآمان مفعل في حسابك. يرجى اختيار وسيلة ثانية للمصادقة:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "تعذر تحميل طريقة واحدة على الأقل من طرق المصادقة الثنائية الممكّنة. الرجاء الاتصال بالمسؤول الخاص بك.",
@@ -378,23 +356,41 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "هذا %s في وضع الصيانة، قد يستغرق ذلك بعض الوقت.",
     "This page will refresh itself when the instance is available again." : "سوف يتم تحديث الصفحة في حين الخادم جاهز للاستخدام مجددا.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "تواصل مع مسؤول النظام اذا استمرت هذه الرسالة بالظهور دائما أو بشكل مفاجئ.",
-    "Currently open" : "مفتوح حاليّاً ",
-    "Login with username or email" : "الدخول باسم المستخدم أو البريد الإلكتروني",
-    "Login with username" : "الدخول باسم المستخدم",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "الدردشة ومكالمات الفيديو ومشاركة الشاشة والإجتماعات عبر الإنترنت ومؤتمرات الويب - في متصفحك ومع تطبيق للهاتف المحمول.",
-    "You have not added any info yet" : "لم تقم بإضافة أي معلومات حتى الآن",
-    "{user} has not added any info yet" : "لم يقم المستخدم {user} بإضافة أي معلومات بعد",
-    "Error opening the user status modal, try hard refreshing the page" : "خطأ في فتح حالة المستخدم ، حاول تحديث الصفحة",
-    "Edit Profile" : "تعديل الملف الشخصي",
-    "The headline and about sections will show up here" : "سيظهر هنا العنوان والأقسام الخاصة بالملف الشخصي",
-    "Error loading message template: {error}" : "حصل خطأ في القالب: {error}",
+    "Error occurred while checking server setup" : "تم العثور على خطأ  اثناء فحص إعدادات الخادم",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "للمزيد من التفاصيل، يرجى الإطلاع على {linkstart} الدليل ↗{linkend}.",
+    "unknown text" : "النص غير معروف",
+    "Hello world!" : "مرحبا بالعالم!",
+    "sunny" : "مشمس",
+    "Hello {name}, the weather is {weather}" : "مرحبًا {name}، حالة الطقس {weather}",
+    "Hello {name}" : "مرحبا {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>هذه هي نتائج البحث الخاصة بك <script>تنبيه(1)</script> </strong>",
+    "new" : "جديد",
+    "_download %n file_::_download %n files_" : ["تنزيل %n ملف","تنزيل ملف واحد","تنزيل ملفين","تنزيل %n ملفات","تنزيل %n ملفات","تنزيل %n ملفات"],
+    "Direct link copied to clipboard" : "تمّ نسخ الرابط المباشر إلى الحافظة",
+    "Searching …" : "يتم الآن البحث…",
+    "Logging in …" : "تسجيل الدخول …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "لقد اكتشفنا عدة محاولات تسجيل دخول غير صالحة من عنوان IP الخاص بك. لذلك تم تقييد تسجيل الدخول التالي الخاص بك حتى 30 ثانية.",
+    "Loading apps …" : "تحميل التطبيقات…",
+    "Installing apps …" : "جاري تثبيت التطبيقات…",
+    "Loading your contacts …" : "تحميل جهات الإتصال",
+    "Looking for {term} …" : "جاري البحث عن {term}",
+    "Search contacts …" : "البحث عن جهات الإتصال",
+    "Loading more results …" : "جاري عرض المزيد من النتائج…",
+    "Search {types} …" : "بحث {types} …",
+    "Saving …" : "جاري الحفظ…",
     "Very weak password" : "كلمة السر ضعيفة جدا",
     "Weak password" : "كلمة السر ضعيفة",
     "So-so password" : "كلمة سر غير فعالة",
     "Good password" : "كلمة السر جيدة",
     "Strong password" : "كلمة السر قوية",
-    "Profile not found" : "ملف المستخدم غير موجود",
-    "The profile does not exist." : "الملف الشخصي غير موجود.",
+    "No action available" : "لا يتوفر أي إجراء",
+    "Error fetching contact actions" : "حدث خطأ أثناء جلب إجراءات جهات الاتصال",
+    "Non-existing tag #{tag}" : "وسم غير موجود #{tag}",
+    "Restricted" : "مقيد",
+    "Delete" : "إلغاء",
+    "Rename" : "إعادة التسمية",
+    "Collaborative tags" : "أوسمة تعاونية",
+    "No tags found" : "لم يُعثَر على أي وسم",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "مجلدات البيانات والملفات الخاصة قد تكون قابلة للوصول اليها عن طريق شبكة الانترنت وذلك بسبب ان ملف .htaccess  لا يعمل بشكل صحيح.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "للحصول على معلومات حول كيفية تكوين الخادم الخاص بك، يرجى الاطلاع على <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">التعليمات</a>.",
     "<strong>Create an admin account</strong>" : "<strong>إنشاء حساب مُشرِف</strong>",
@@ -404,6 +400,10 @@ OC.L10N.register(
     "Toggle password visibility" : "تبديل قراءة كلمة المرور",
     "Configure the database" : "إعداد قاعدة البيانات",
     "Only %s is available." : "لم يتبقى إلّا %s.",
-    "Database account" : "حساب قاعدة البيانات"
+    "Database account" : "حساب قاعدة البيانات",
+    "Installing …" : "جاري التثبيت...",
+    "Please log in before granting %1$s access to your %2$s account." : "يرجى تسجيل الدخول قبل الحصول على اذن %1$s في حسابك %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "مسجّل حاليّاً كـ %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "انت على وشك الحصول على اذن %1$s لحسابك %2$s."
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
