@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Unbekannter Dateityp",
     "An error occurred. Please contact your admin." : "Es ist ein Fehler aufgetreten. Bitte kontaktiere deine Administration.",
     "Invalid image" : "Ungültiges Bild",
-    "No temporary profile picture available, try again" : "Kein temporäres Profilbild verfügbar, bitte versuche es noch einmal",
-    "No crop data provided" : "Keine Beschnittdaten zur Verfügung gestellt",
-    "No valid crop data provided" : "Keine gültigen Zuschnittdaten zur Verfügung gestellt",
-    "Crop is not square" : "Zuschnitt ist nicht quadratisch",
     "State token does not match" : "Status-Token stimmen nicht überein",
     "Invalid app password" : "Ungültiges App-Passwort",
     "Could not complete login" : "Anmeldung konnte nicht abgeschlossen werden",
@@ -46,6 +42,7 @@ OC.L10N.register(
     "Not found" : "Nicht gefunden",
     "Node is locked" : "Knoten ist gesperrt",
     "Bad request" : "Fehlerhafte Anfrage",
+    "Input text is too long" : "Eingabetext ist zu lang",
     "Requested task type does not exist" : "Angeforderter Aufgabentyp existiert nicht",
     "Necessary language model provider is not available" : "Erforderlicher Sprachmodellanbieter ist nicht verfügbar",
     "No text to image provider is available" : "Es ist kein Text-zu-Bild-Anbieter verfügbar",
@@ -53,6 +50,7 @@ OC.L10N.register(
     "No translation provider available" : "Kein Übersetzungsanbieter verfügbar",
     "Could not detect language" : "Sprache konnte nicht erkannt werden",
     "Unable to translate" : "Kann nicht übersetzt werden",
+    "No valid filters provided" : "Keine gültigen Filter angegeben",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Reparaturschritt:",
     "Repair info:" : "Reparaturinformation:",
@@ -200,16 +198,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska-Video",
     "Windows Media video" : "Windows Media-Video",
     "AVI video" : "AVI-Video",
-    "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Weitere Informationen findest du in der {linkstart}Dokumentation ↗{linkend}.",
-    "unknown text" : "Unbekannter Text",
-    "Hello world!" : "Hallo Welt!",
-    "sunny" : "sonnig",
-    "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
-    "Hello {name}" : "Hallo {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dies sind deine Suchergebnisse<script>alert(1)</script></strong>",
-    "new" : "Neu",
-    "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Die Aktualisierung wird durchgeführt. Wenn du dieses Fenster verlässt, kann dies den Aktualisierungsprozess in manchen Umgebungen unterbrechen.",
     "Update to {version}" : "Aktualisierung auf {version}",
     "An error occurred." : "Es ist ein Fehler aufgetreten.",
@@ -218,19 +206,25 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Das Update ist fehlgeschlagen. Bitte melde dieses Problem an die <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud Community</a>.",
     "Continue to {productName}" : "Fortfahren zu {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Die Aktualisierung war erfolgreich. Du wirst in %n Sekunden zu {productName} weitergeleitet.","Die Aktualisierung war erfolgreich. Du wirst in %n Sekunden zu {productName} weitergeleitet."],
+    "Done" : "Erledigt",
+    "Scan QR code to log in" : "QR-Code zum Anmelden scannen",
+    "Use {productName} mobile client you want to connect to scan the code" : "Den mobilen {productName}-Client wählen, der zum Scannen des Codes verwendet werden soll",
+    "Code will expire {timeCountdown} or after use" : "Der Code läuft bei Verwendung oder nach {timeCountdown} ab",
     "Applications menu" : "Anwendungs-Menü",
     "Apps" : "Apps",
     "More apps" : "Weitere Apps",
     "_{count} notification_::_{count} notifications_" : ["{count} Benachrichtigung","{count} Benachrichtigungen"],
     "No" : "Nein",
     "Yes" : "Ja",
+    "App password" : "App-Passwort",
+    "Grant access" : "Zugriff gewähren",
     "The remote URL must include the user." : "Die entfernte URL muss den Benutzer enthalten.",
     "Invalid remote URL." : "Ungültige entfernte URL.",
     "Failed to add the public link to your Nextcloud" : "Der öffentliche Link konnte nicht zu deiner Nextcloud hinzugefügt werden",
     "Federated user" : "Federated Benutzer",
     "user@your-nextcloud.org" : "benutzer@deine-nextcloud.org",
     "Create share" : "Freigabe erstellen",
-    "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert",
+    "Direct link copied" : "Direktlink kopiert",
     "Please copy the link manually:" : "Bitte den Link manuell kopieren:",
     "Custom date range" : "Benutzerdefinierter Zeitbereich",
     "Pick start date" : "Startdatum wählen",
@@ -239,14 +233,16 @@ OC.L10N.register(
     "Search in current app" : "In aktueller App suchen ",
     "Clear search" : "Suche löschen",
     "Search everywhere" : "Überall suchen",
-    "Searching …" : "Suche …",
+    "Searching …" : "Suche …",
     "Start typing to search" : "Beginne mit der Eingabe, um zu suchen",
+    "Minimum search length is {minSearchLength} characters" : "Die Mindestsuchlänge beträgt {minSearchLength} Zeichen",
     "No matching results" : "Keine passenden Suchergebnisse",
     "Today" : "Heute",
     "Last 7 days" : "Die letzten 7 Tage",
     "Last 30 days" : "Die letzten 30 Tage",
     "This year" : "Dieses Jahr",
     "Last year" : "Letztes Jahr",
+    "Between {startDate} and {endDate}" : "Von {startDate} bis {endDate}",
     "Unified search" : "Einheitliche Suche",
     "Search apps, files, tags, messages" : "Nach Apps, Dateien, Schlagworten und Nachrichten suchen",
     "Places" : "Orte",
@@ -254,15 +250,17 @@ OC.L10N.register(
     "Search people" : "Personen suchen",
     "People" : "Personen",
     "Filter in current view" : "Filter in aktueller Ansicht",
+    "Search connected services" : "Verbundene Dienste durchsuchen",
     "Results" : "Ergebnisse",
     "Load more results" : "Weitere Ergebnisse laden",
     "Search in" : "Suche in",
+    "Partial matches" : "Teilübereinstimmungen",
     "Log in" : "Anmelden",
-    "Logging in …" : "Melde an…",
+    "Logging in …" : "Melde an …",
     "Log in to {productName}" : "Anmelden bei {productName}",
     "Wrong login or password." : "Kontoname oder Passwort falsch",
     "This account is disabled" : "Dieses Konto ist deaktiviert",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Es wurden mehrere ungültige Anmeldeversuche von deiner IP-Adresse festgestellt. Daher wird die nächste Anmeldung um 30 Sekunden verzögert.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Zu viele falsche Anmeldeversuche. Bitte in 30 Sekunden erneut versuchen.",
     "Account name or email" : "Kontoname oder E-Mail-Adresse",
     "Account name" : "Name des Kontos",
     "Server side authentication failed!" : "Serverseitige Authentifizierung fehlgeschlagen!",
@@ -272,6 +270,7 @@ OC.L10N.register(
     "An internal error occurred." : "Es ist ein interner Fehler aufgetreten.",
     "Please try again or contact your administrator." : "Bitte versuche es noch einmal oder kontaktiere die Administration.",
     "Password" : "Passwort",
+    "Remember me" : "An mich erinnern",
     "Log in with a device" : "Mit einem Gerät anmelden",
     "Login or email" : "Kontoname oder E-Mail-Adresse",
     "Your account is not setup for passwordless login." : "Dein Konto ist nicht für eine Anmeldung ohne Passwort eingerichtet.",
@@ -295,21 +294,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Gemeinsame Dokumente, Tabellenkalkulationen und Präsentationen, die auf Collabora Online basieren.",
     "Distraction free note taking app." : "Ablenkungsfreie Notizen-App",
     "Recommended apps" : "Empfohlene Apps",
-    "Loading apps …" : "Lade Apps …",
+    "Loading apps …" : "Lade Apps …",
     "Could not fetch list of apps from the App Store." : "Liste der Apps konnte nicht vom App-Store abgerufen werden",
     "App download or installation failed" : "Herunterladen oder Installieren der App fehlgeschlagen",
     "Cannot install this app because it is not compatible" : "App kann nicht installiert werden, da sie inkompatibel ist",
     "Cannot install this app" : "App kann nicht installiert werden",
     "Skip" : "Überspringen",
-    "Installing apps …" : "Installiere Apps …",
+    "Installing apps …" : "Installiere Apps …",
     "Install recommended apps" : "Empfohlene Apps installieren",
+    "Online" : "Online",
+    "Away" : "Abwesend",
+    "Busy" : "Beschäftigt",
+    "Do not disturb" : "Bitte nicht stören",
+    "Mute all notifications" : "Alle Benachrichtigungen stummschalten",
+    "Invisible" : "Unsichtbar",
+    "Appear offline" : "Offline erscheinen",
     "Avatar of {displayName}" : "Avatar von {displayName}",
     "Settings menu" : "Einstellungen-Menü",
-    "Loading your contacts …" : "Lade deine Kontakte …",
-    "Looking for {term} …" : "Suche nach {term} …",
+    "Loading your contacts …" : "Lade deine Kontakte …",
+    "Looking for {term} …" : "Suche nach {term} …",
     "Search contacts" : "Kontakte suchen",
     "Reset search" : "Suche zurücksetzen",
-    "Search contacts …" : "Kontakte suchen …",
+    "Search contacts …" : "Kontakte suchen …",
     "Could not load your contacts" : "Deine Kontakte konnten nicht geladen werden",
     "No contacts found" : "Keine Kontakte gefunden",
     "Show all contacts" : "Alle Kontakte anzeigen",
@@ -321,13 +327,39 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Es ist ein Fehler beim Suchen nach {type} aufgetreten",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Die Suche beginnt, sobald du mit der Eingabe beginnst. Die Suchergebnisse kannst du mit den Pfeiltasten auswählen,",
     "Search for {name} only" : "Nur nach {name} suchen",
-    "Loading more results …" : "Lade weitere Ergebnisse …",
+    "Loading more results …" : "Lade weitere Ergebnisse …",
     "Forgot password?" : "Passwort vergessen?",
     "Back to login form" : "Zurück zum Anmeldeformular",
     "Back" : "Zurück",
     "Login form is disabled." : "Das Anmeldeformular ist deaktiviert.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Das Nextcloud-Anmeldeformular ist deaktiviert. Nutze ggf. eine andere Anmeldemöglichkeit oder wende dich an deine Administration.",
+    "Connect to your account" : "Verbinde dich mit deinem Konto",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Bitte anmelden, bevor du \"{client}\" Zugriff auf dein {instanceName}-Konto gewährst.",
+    "Security warning" : "Sicherheitswarnung",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Solltest du aktuell nicht versuchen, ein neues Gerät oder eine neue App einzurichten, dann kann es sein, dass jemand versucht, dich dazu zu bewegen, ihm Zugriff auf deine Daten zu gewähren. Fahre in diesem Fall nicht fort, sondern wende dich an deine Administration.",
+    "Log in using password" : "Mit Passwort anmelden",
+    "Alternative log in using app password" : "Alternative Anmeldung mittels App-Passwort",
+    "Account connected" : "Konto verbunden",
+    "Your client should now be connected!" : "Dein Client sollte nun verbunden sein!",
+    "You can close this window." : "Du kannst dieses Fenster schließen.",
+    "Account access" : "Kontozugriff ",
+    "Currently logged in as {userDisplayName} ({userId})." : "Aktuell angemeldet als {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Du bist dabei, \"{client}\" Zugriff auf dein {instanceName}-Konto zu gewähren.",
     "More actions" : "Weitere Aktionen",
+    "User menu" : "Benutzermenü",
+    "Your guest name: {user}" : "Dein Gastname: {user}",
+    "You are currently not identified." : "Du bist derzeit nicht identifiziert.",
+    "Set public name" : "Öffentlichen Namen festlegen",
+    "Change public name" : "Öffentlichen Namen ändern",
+    "This share is password-protected" : "Diese Freigabe ist passwortgeschützt",
+    "The password is wrong or expired. Please try again or request a new one." : "Das Passwort ist falsch oder abgelaufen. Bitte erneut versuchen oder ein neues Passwort anfordern.",
+    "Submit" : "Übermitteln",
+    "Please type in your email address to request a temporary password" : "Bitte gib deine E-Mail-Adresse ein, um ein vorläufiges Passwort anzufordern",
+    "Password sent!" : "Passwort wurde verschickt",
+    "You are not authorized to request a password for this share" : "Du bist nicht berechtigt, für diese Freigabe ein Passwort anzufordern",
+    "Email address" : "E-Mail-Adresse",
+    "Request password" : "Passwort anfordern",
+    "Forgot password" : "Passwort vergessen",
     "Password is too weak" : "Passwort ist zu schwach",
     "Password is weak" : "Passwort ist schwach",
     "Password is average" : "Passwort ist durchschnittlich",
@@ -338,14 +370,14 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Dein Datenverzeichnis und deine Dateien sind wahrscheinlich über das Internet zugänglich, da die <code>.htaccess</code>-Datei nicht funktioniert.",
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Informationen zur ordnungsgemäßen Konfiguration des Servers sind {linkStart}in der Dokumentation zu finden{linkEnd}",
     "Autoconfig file detected" : "Autoconfig-Datei erkannt",
-    "The setup form below is pre-filled with the values from the config file." : "Das folgende Setup-Formular ist mit den Werten aus der Konfigurationsdatei vorausgefüllt.",
-    "Security warning" : "Sicherheitswarnung",
+    "The setup form below is pre-filled with the values from the config file." : "Das folgende Einrichtungsformular ist mit den Werten aus der Konfigurationsdatei vorausgefüllt.",
     "Create administration account" : "Administrationskonto erstellen",
     "Administration account name" : "Name des Administrationskontos",
     "Administration account password" : "Passwort des Administrationskontos",
     "Storage & database" : "Speicher & Datenbank",
     "Data folder" : "Datenverzeichnis",
     "Database configuration" : "Datenbankkonfiguration",
+    "Database type" : "Datenbank-Typ",
     "Only {firstAndOnlyDatabase} is available." : "Nur {firstAndOnlyDatabase} ist verfügbar",
     "Install and activate additional PHP modules to choose other database types." : "Um weitere Datenbank-Typen auswählen zu können, müssen zusätzliche PHP-Module installiert und aktiviert werden.",
     "For more details check out the documentation." : "Schau für weitere Informationen in die Dokumentation.",
@@ -353,6 +385,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Du hast SQLite als Datenbanktyp ausgewählt.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sollte nur für Minimal- und Entwicklungsinstanzen gewählt werden. Für die Produktion wird ein anderes Datenbank-Backend empfohlen.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Wenn Clients für die Dateisynchronisierung verwenden werden, so wird von der Verwendung von SQLite dringend abgeraten.",
+    "Database connection" : "Datenbankverbindung",
     "Database user" : "Datenbank-Benutzer",
     "Database password" : "Datenbank-Passwort",
     "Database name" : "Datenbank-Name",
@@ -360,7 +393,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bitte die Portnummer mit der Hostadresse zusammen angeben (z. B. localhost:5432)",
     "Database host" : "Datenbank-Host",
     "localhost" : "localhost",
-    "Installing …" : "Installiere …",
+    "Installing …" : "Installiere …",
     "Install" : "Installieren",
     "Need help?" : "Hilfe nötig?",
     "See the documentation" : "Schau in die Dokumentation",
@@ -369,7 +402,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Dein Browser wird nicht unterstützt. Bitte aktualisieren deinen Browser auf eine neuere oder unterstützte Version.",
     "Continue with this unsupported browser" : "Mit diesem nicht unterstützten Browser fortfahren.",
     "Supported versions" : "Unterstützte Versionen",
-    "Search {types} …" : "Suche {types} …",
+    "Search {types} …" : "Suche {types} …",
     "Choose {file}" : "{file} auswählen",
     "Choose" : "Auswählen",
     "Copy to {target}" : "Nach {target} kopieren",
@@ -389,7 +422,10 @@ OC.L10N.register(
     "(all selected)" : "(Alle ausgewählt)",
     "({count} selected)" : "({count} ausgewählt)",
     "Error loading file exists template" : "Fehler beim Laden der vorhanden Dateivorlage",
-    "Saving …" : "Speichern …",
+    "Saving …" : "Speichere …",
+    "Groups" : "Gruppen",
+    "Group list is empty" : "Gruppenliste ist leer",
+    "Unable to retrieve the group list" : "Gruppenliste konnte nicht abgerufen werden",
     "seconds ago" : "Gerade eben",
     "Connection to server lost" : "Verbindung zum Server verloren",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem beim Laden der Seite, Seite wird in %n Sekunde nochmals geladen","Problem beim Laden der Seite, Seite wird in %n Sekunden erneut geladen"],
@@ -404,17 +440,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Nach existierenden Projekten suchen",
     "New in" : "Neu in",
     "View changelog" : "Liste der Veränderungen ansehen",
-    "No action available" : "Keine Aktion verfügbar",
-    "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
     "Close \"{dialogTitle}\" dialog" : "Dialog \"{dialogTitle}\" schließen",
     "Email length is at max (255)" : "Maximale Länge der E-Mail-Adresse erreicht (255)",
-    "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
-    "Restricted" : "Eingeschränkt",
-    "Invisible" : "Unsichtbar",
-    "Delete" : "Löschen",
-    "Rename" : "Umbenennen",
-    "Collaborative tags" : "Kollaborative Schlagworte",
-    "No tags found" : "Keine Tags gefunden",
     "Clipboard not available, please copy manually" : "Zwischenablage nicht verfügbar, bitte manuell kopieren",
     "Personal" : "Persönlich",
     "Accounts" : "Konten",
@@ -449,25 +476,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Zum Navigationsbereich der App springen",
     "Go to %s" : "%s aufrufen",
     "Get your own free account" : "Hole dir dein eigenes kostenloses Konto",
-    "Connect to your account" : "Verbinde dich mit deinem Konto",
-    "Please log in before granting %1$s access to your %2$s account." : "Bitte melde dich an, bevor du %1$s Zugriff auf dein %2$s-Konto gewährst.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Solltest du aktuell nicht versuchen, ein neues Gerät oder eine neue App einzurichten, dann kann es sein, dass jemand versucht, dich dazu zu bewegen, ihm Zugriff auf deine Daten zu gewähren. Fahre in diesem Fall nicht fort, sondern wende dich an deine Administration.",
-    "App password" : "App-Passwort",
-    "Grant access" : "Zugriff gewähren",
-    "Alternative log in using app password" : "Alternative Anmeldung mittels App-Passwort",
-    "Account access" : "Kontozugriff ",
-    "Currently logged in as %1$s (%2$s)." : "Aktuell angemeldet als %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Du bist dabei, %1$s Zugriff auf dein %2$s-Konto zu gewähren.",
-    "Account connected" : "Konto verbunden",
-    "Your client should now be connected!" : "Dein Client sollte nun verbunden sein!",
-    "You can close this window." : "Du kannst dieses Fenster schließen.",
     "Previous" : "Vorige",
-    "This share is password-protected" : "Diese Freigabe ist passwortgeschützt",
-    "The password is wrong or expired. Please try again or request a new one." : "Das Passwort ist falsch oder abgelaufen. Bitte versuche es erneut oder forder ein neues Passwort an.",
-    "Please type in your email address to request a temporary password" : "Bitte gib deine E-Mail-Adresse ein, um ein vorläufiges Passwort anzufordern",
-    "Email address" : "E-Mail-Adresse",
-    "Password sent!" : "Passwort wurde verschickt",
-    "You are not authorized to request a password for this share" : "Du bist nicht berechtigt, für diese Freigabe ein Passwort anzufordern",
     "Two-factor authentication" : "Zwei-Faktor-Authentifizierung",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Die erweiterte Sicherheit wurde für dein Konto aktiviert. Bitte wähle einen zweiten Faktor für die Authentifizierung:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Mindestens eine deiner Zwei-Faktor-Authentifizierungsmethoden konnte nicht geladen werden. Kontaktiere deine Administration.",
@@ -480,7 +489,7 @@ OC.L10N.register(
     "Enhanced security is enforced for your account. Choose which provider to set up:" : "Erhöhte Sicherheit ist für dein Konto aktiviert. Bitte wähle einen Anbieter zum Einrichten: ",
     "Error while validating your second factor" : "Fehler beim Bestätigen des zweiten Sicherheitsfaktors",
     "Access through untrusted domain" : "Zugriff über eine nicht vertrauenswürdige Domain",
-    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bitte kontaktiere deine Administration. Wenn du Administrator bist,  bearbeite die \"trusted_domains\"-Einstellung in config/config.php. Siehe Beispiel in config/config.sample.php.",
+    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bitte kontaktiere deine Administration. Wenn du der Administration angehörst,  bearbeite die \"trusted_domains\"-Einstellung in config/config.php. Siehe Beispiel in config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Weitere Informationen zur Konfiguration finden sich in der %1$sDokumentation%2$s.",
     "App update required" : "App-Aktualisierung notwendig",
     "%1$s will be updated to version %2$s" : "%1$s wird auf Version %2$s aktualisiert",
@@ -498,21 +507,43 @@ OC.L10N.register(
     "Upgrade via web on my own risk" : "Aktualisierung über die Web-Oberfläche auf eigenes Risiko",
     "Maintenance mode" : "Wartungsmodus",
     "This %s instance is currently in maintenance mode, which may take a while." : "Diese Instanz der %s - befindet sich gerade im Wartungsmodus, was eine Weile dauern kann.",
-    "This page will refresh itself when the instance is available again." : "Diese Seite aktualisiert sich automatisch, sobald die Nextcloud-Instanz wieder verfügbar ist.",
+    "This page will refresh itself when the instance is available again." : "Diese Seite aktualisiert sich automatisch, sobald diese Instanz wieder verfügbar ist.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktiere die Systemadministration, wenn diese Meldung dauerhaft oder unerwartet erscheint.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, Videoanrufe, Bildschirmfreigaben, Online-Besprechungen und Webkonferenzen - in deinem Browser sowie mit mobilen Apps.",
-    "You have not added any info yet" : "Du hast noch keine Infos hinzugefügt",
-    "{user} has not added any info yet" : "{user} hat noch keine Infos hinzugefügt",
-    "Error opening the user status modal, try hard refreshing the page" : "Fehler beim Modal-öffnen des Benutzerstatus, versuche die Seite zu aktualisieren",
-    "Edit Profile" : "Profil bearbeiten",
-    "The headline and about sections will show up here" : "Die Überschrift und der Infobereich werden hier angezeigt",
+    "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Weitere Informationen findest du in der {linkstart}Dokumentation ↗{linkend}.",
+    "unknown text" : "Unbekannter Text",
+    "Hello world!" : "Hallo Welt!",
+    "sunny" : "sonnig",
+    "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
+    "Hello {name}" : "Hallo {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dies sind deine Suchergebnisse<script>alert(1)</script></strong>",
+    "new" : "Neu",
+    "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
+    "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert",
+    "Searching …" : "Suche …",
+    "Logging in …" : "Melde an…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Es wurden mehrere ungültige Anmeldeversuche von deiner IP-Adresse festgestellt. Daher wird die nächste Anmeldung um 30 Sekunden verzögert.",
+    "Loading apps …" : "Lade Apps …",
+    "Installing apps …" : "Installiere Apps …",
+    "Loading your contacts …" : "Lade deine Kontakte …",
+    "Looking for {term} …" : "Suche nach {term} …",
+    "Search contacts …" : "Kontakte suchen …",
+    "Loading more results …" : "Lade weitere Ergebnisse …",
+    "Search {types} …" : "Suche {types} …",
+    "Saving …" : "Speichern …",
     "Very weak password" : "Sehr schwaches Passwort",
     "Weak password" : "Schwaches Passwort",
     "So-so password" : "Passables Passwort",
     "Good password" : "Gutes Passwort",
     "Strong password" : "Starkes Passwort",
-    "Profile not found" : "Profil nicht gefunden",
-    "The profile does not exist." : "Das Profil existiert nicht",
+    "No action available" : "Keine Aktion verfügbar",
+    "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
+    "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
+    "Restricted" : "Eingeschränkt",
+    "Delete" : "Löschen",
+    "Rename" : "Umbenennen",
+    "Collaborative tags" : "Kollaborative Schlagworte",
+    "No tags found" : "Keine Tags gefunden",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dein Datenverzeichnis und deine Dateien sind wahrscheinlich vom Internet aus erreichbar, weil die .htaccess-Datei nicht funktioniert.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informationen zum richtigen Konfigurieren deines Servers kannst du der <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">Dokumentation</a> entnehmen.",
     "<strong>Create an admin account</strong>" : "<strong>Administrationskonto anlegen</strong>",
@@ -522,6 +553,10 @@ OC.L10N.register(
     "Toggle password visibility" : "Passwortsichtbarkeit umschalten",
     "Configure the database" : "Datenbank einrichten",
     "Only %s is available." : "Es ist nur %s verfügbar.",
-    "Database account" : "Datenbankkonto"
+    "Database account" : "Datenbankkonto",
+    "Installing …" : "Installiere …",
+    "Please log in before granting %1$s access to your %2$s account." : "Bitte melde dich an, bevor du %1$s Zugriff auf dein %2$s-Konto gewährst.",
+    "Currently logged in as %1$s (%2$s)." : "Aktuell angemeldet als %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Du bist dabei, %1$s Zugriff auf dein %2$s-Konto zu gewähren."
 },
 "nplurals=2; plural=(n != 1);");
