@@ -344,6 +344,15 @@ OC.L10N.register(
     "You are currently not identified." : "Momentálne nie ste identifikovaní.",
     "Set public name" : "Nastaviť verejné meno",
     "Change public name" : "Zmeniť verejné meno",
+    "This share is password-protected" : "Toto zdieľanie je chránené heslom",
+    "The password is wrong or expired. Please try again or request a new one." : "Heslo je nesprávne alebo jeho platnosť vypršala. Skúste to znova alebo požiadajte o nové heslo.",
+    "Submit" : "Odoslať",
+    "Please type in your email address to request a temporary password" : "Prosím zadajte vašu e-mailovú adresu pre získanie dočasného hesla",
+    "Password sent!" : "Heslo odoslané!",
+    "You are not authorized to request a password for this share" : "Nemáte oprávnenie žiadať o heslo pre toto zdieľanie",
+    "Email address" : "E-mailová adresa",
+    "Request password" : "Vyžiadať heslo",
+    "Forgot password" : "Zabudnuté heslo",
     "Password is too weak" : "Heslo je príliš jednoduché",
     "Password is weak" : "Heslo je jednoduché",
     "Password is average" : "Heslo je priemerné",
@@ -461,12 +470,6 @@ OC.L10N.register(
     "Go to %s" : "Prejsť na %s",
     "Get your own free account" : "Získajte zdarma svoj vlastný účet",
     "Previous" : "Predchádzajúce",
-    "This share is password-protected" : "Toto zdieľanie je chránené heslom",
-    "The password is wrong or expired. Please try again or request a new one." : "Heslo je nesprávne alebo jeho platnosť vypršala. Skúste to znova alebo požiadajte o nové heslo.",
-    "Please type in your email address to request a temporary password" : "Prosím zadajte vašu e-mailovú adresu pre získanie dočasného hesla",
-    "Email address" : "E-mailová adresa",
-    "Password sent!" : "Heslo odoslané!",
-    "You are not authorized to request a password for this share" : "Nemáte oprávnenie žiadať o heslo pre toto zdieľanie",
     "Two-factor authentication" : "Dvojfázové overovanie",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Vylepšená bezpečnosť je pre váš účet povolená. Vyberte druhý faktor overenia:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedá sa načítať minimálne jeden z vašich povolených spôsobov na dvojfázové overovanie. Kontaktujte prosím správcu systému.",
