@@ -45,8 +45,6 @@ OC.L10N.register(
     "Input text is too long" : "輸入文字太長",
     "Requested task type does not exist" : "請求的任務類型不存在",
     "Necessary language model provider is not available" : "沒有可用的語言模型提供者",
-    "Cannot generate more than 12 images" : "無法產生超過 12 張圖像",
-    "Cannot generate less than 1 image" : "至少需要產生 1 張圖片",
     "No text to image provider is available" : "沒有可用的文字轉圖像提供者",
     "Image not found" : "找不到圖像",
     "No translation provider available" : "沒有可用翻譯提供者",
@@ -200,10 +198,15 @@ OC.L10N.register(
     "Matroska video" : "Matroska 視頻",
     "Windows Media video" : "Windows Media 視頻",
     "AVI video" : "AVI 視頻",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些狀況下，離開本頁面可能會導致更新中斷",
+    "Update to {version}" : "更新到 {version}",
+    "An error occurred." : "發生錯誤。",
+    "Please reload the page." : "請重新整理頁面。",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗。<a href=\"{url}\">請查看我們關於此問題的論壇帖子</a>來瞭解更多。",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新不成功。請在 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>舉報此問題。",
+    "Continue to {productName}" : "前往 {productName}",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，將在 %n 秒後重導向至 {productName}。"],
     "Done" : "完成",
-    "Scan QR code to log in" : "掃描 QR code 以登入",
-    "Use {productName} mobile client you want to connect to scan the code" : "使用您要連線的 {productName} 行動裝置客戶端掃描此條碼",
-    "Code will expire {timeCountdown} or after use" : "條碼會在 {timeCountdown} 後或使用後失效",
     "Applications menu" : "應用程式選項單",
     "Apps" : "應用程式",
     "More apps" : "更多應用程式",
@@ -270,7 +273,7 @@ OC.L10N.register(
     "Your account is not setup for passwordless login." : "你的賬號尚未設定免密碼登入。",
     "Your connection is not secure" : "您的連線不安全",
     "Passwordless authentication is only available over a secure connection." : "無密碼身分驗證僅支援經加密的連線。",
-    "Browser not supported" : "不支援該瀏覽器",
+    "Browser not supported" : "不支持該瀏覽器",
     "Passwordless authentication is not supported in your browser." : "你使用的瀏覽器不支援無密碼身分驗證。",
     "Reset password" : "重設密碼",
     "Back to login" : "回到登入畫面",
@@ -308,14 +311,10 @@ OC.L10N.register(
     "Loading your contacts …" : "正在載入您的聯絡人 ……",
     "Looking for {term} …" : "正在尋找 {term} ……",
     "Search contacts" : "搜尋聯絡人",
-    "Filter by team" : "以團隊過濾",
-    "All teams" : "所有團隊",
-    "Search contacts in team {team}" : "在 {team} 團隊中搜尋聯絡人",
-    "Search contacts …" : "搜尋聯絡人 ……",
     "Reset search" : "重設搜尋",
+    "Search contacts …" : "搜尋聯絡人 ……",
     "Could not load your contacts" : "無法載入您的聯絡人",
     "No contacts found" : "找不到聯絡人",
-    "Contacts list" : "聯絡人清單",
     "Show all contacts" : "顯示所有聯絡人",
     "Install the Contacts app" : "安裝「通訊錄」應用程式",
     "Search" : "搜尋",
@@ -332,17 +331,13 @@ OC.L10N.register(
     "Login form is disabled." : "登入表格已停用",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登入表單已停用。使用其他登入選項（若可用）或聯絡您的管理人員。",
     "Connect to your account" : "連結您的賬號",
-    "Please log in before granting \"{client}\" access to your {instanceName} account." : "請先登入，再授權「{client}」存取您 {instanceName} 帳號。",
     "Security warning" : "安全性警示",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若你並未嘗試在新的裝置登入你的帳戶，有什麼人證在嘗試登入你的帳戶並存取你的個人資料。大多數情況你並不用作任何應對，但也可通知你的系統管理員。",
-    "Log in using password" : "使用密碼登入",
     "Alternative log in using app password" : "使用應用程式密碼來登入",
     "Account connected" : "帳戶已連結",
     "Your client should now be connected!" : "客戶端應該已完成連線",
     "You can close this window." : "可以關閉此視窗",
     "Account access" : "帳戶存取",
-    "Currently logged in as {userDisplayName} ({userId})." : "目前登入為 {userDisplayName} ({userId})。",
-    "You are about to grant \"{client}\" access to your {instanceName} account." : "您將要授權「{client}」存取您的 {instanceName} 帳號。",
     "More actions" : "更多操作",
     "User menu" : "用戶選項單",
     "Your guest name: {user}" : "您的訪客名稱：{user}",
@@ -357,7 +352,6 @@ OC.L10N.register(
     "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
     "Email address" : "電郵地址",
     "Request password" : "索取密碼",
-    "Forgot password" : "忘記密碼",
     "Password is too weak" : "密碼強度非常弱",
     "Password is weak" : "密碼強度弱",
     "Password is average" : "密碼強度一般",
@@ -400,32 +394,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
     "Continue with this unsupported browser" : "繼續使用此不受支援的瀏覽器",
     "Supported versions" : "支援的版本",
-    "The update completed with warnings. Please check the details for more information." : "更新已完成，但出現警告。請查看詳細資料以了解更多資訊。",
-    "The update completed successfully." : "更新已成功完成。",
-    "Preparing update…" : "正在準備更新…",
-    "You will be redirected to {productName} in {count} seconds." : "系統將於 {count} 秒後重新導向至 {productName}。",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些狀況下，離開本頁面可能會導致更新中斷",
-    "App update required" : "需要更新應用程式",
-    "{productName} will be updated to version {version}" : "{productName} 將更新至版本 {version}",
-    "The theme {oldTheme} has been disabled." : "主題 {oldTheme} 已被停用。",
-    "These incompatible apps will be disabled:" : "以下不兼容的應用程式將被停用：",
-    "Incompatible apps" : "不兼容的應用程式",
-    "These apps will be updated:" : "將會更新這些應用程式",
-    "Apps to update" : "需要更新的應用程式",
-    "{app} from {oldVersion} to {version}" : "{app}：由 {oldVersion} 更新至 {version}",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份數據庫、config 資料夾及數據資料夾",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "為避免大型安裝超時，您可以改為從安裝目錄下運行以下指令：",
-    "Start update" : "開始升級",
-    "Continue to {productName}" : "前往 {productName}",
-    "Update to {version}" : "更新到 {version}",
-    "Hide details" : "隱藏細節",
-    "Show details" : "顯示細節",
-    "Update details" : "更新詳情",
-    "Update needed" : "需要更新",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因為您有超過50名帳戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。",
-    "Documentation" : "說明書",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "若我繼續透過網頁界面更新時我已了解有其風險，若請求逾時可能導致資料遺失，萬一更新失敗，我已準備好備份並知道如何回復運作。",
-    "Upgrade via web on my own risk" : "願意承擔風險透過網頁更新",
     "Search {types} …" : "搜尋 {types} ……",
     "Choose {file}" : "選擇 {file}",
     "Choose" : "選擇",
@@ -451,13 +419,19 @@ OC.L10N.register(
     "Group list is empty" : "群組列表為空",
     "Unable to retrieve the group list" : "無法擷取群組列表",
     "seconds ago" : "幾秒前",
+    "Connection to server lost" : "伺服器連線中斷",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時出錯，%n 秒後重新整理"],
     "Add to a project" : "加到專案",
+    "Show details" : "顯示細節",
+    "Hide details" : "隱藏細節",
     "Rename project" : "重新命名專案",
     "Failed to rename the project" : "重新命名專案失敗",
     "Failed to create a project" : "建立專案失敗",
     "Failed to add the item to the project" : "新增項目至專案時失敗",
     "Connect items to a project to make them easier to find" : "將項目連結到專案以便尋找",
     "Type to search for existing projects" : "搜尋現有專案",
+    "New in" : "新加入",
+    "View changelog" : "檢視版本更新紀錄",
     "Close \"{dialogTitle}\" dialog" : "關閉 \"{dialogTitle}\" 對話",
     "Email length is at max (255)" : "電子郵件已達到最大長度（255 個字元）",
     "Clipboard not available, please copy manually" : "剪貼板不可用，請人手複製",
@@ -509,6 +483,20 @@ OC.L10N.register(
     "Access through untrusted domain" : "經由不可信任的域名存取。",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "請聯絡您的管理員。如果您就是管理員，請模仿 config.sample.php 範例編輯 config/config.php 的「trusted_domains」設定。",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "更多關於如何設定的資訊，請見%1$s文件%2$s。",
+    "App update required" : "需要更新應用程式",
+    "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
+    "The following apps will be updated:" : "將更新以下的 APP：",
+    "These incompatible apps will be disabled:" : "以下不兼容的應用程式將被停用：",
+    "The theme %s has been disabled." : "主題 %s 已經被停用。",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份數據庫、config 資料夾及數據資料夾",
+    "Start update" : "開始升級",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "為避免大型安裝超時，您可以改為從安裝目錄下運行以下指令：",
+    "Detailed logs" : "詳細記錄檔",
+    "Update needed" : "需要更新",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因為您有超過50名帳戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "若我繼續透過網頁界面更新時我已了解有其風險，若請求逾時可能導致資料遺失，萬一更新失敗，我已準備好備份並知道如何回復運作。",
+    "Upgrade via web on my own risk" : "願意承擔風險透過網頁更新",
     "Maintenance mode" : "維護模式",
     "This %s instance is currently in maintenance mode, which may take a while." : "此 %s 實例目前處於維護模式，可能需要一段時間才能完成。",
     "This page will refresh itself when the instance is available again." : "安裝恢復可用之後，本頁會自動重新整理",
@@ -523,11 +511,6 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告（1）</script></strong>",
     "new" : "新",
     "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
-    "An error occurred." : "發生錯誤。",
-    "Please reload the page." : "請重新整理頁面。",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗。<a href=\"{url}\">請查看我們關於此問題的論壇帖子</a>來瞭解更多。",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新不成功。請在 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>舉報此問題。",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，將在 %n 秒後重導向至 {productName}。"],
     "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
     "Searching …" : "正在搜尋……",
     "Logging in …" : "正在登入 …",
@@ -540,10 +523,6 @@ OC.L10N.register(
     "Loading more results …" : "正在載入更多結果...",
     "Search {types} …" : "搜尋 {types} 中 …",
     "Saving …" : "儲存中 ...",
-    "Connection to server lost" : "伺服器連線中斷",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時出錯，%n 秒後重新整理"],
-    "New in" : "新加入",
-    "View changelog" : "檢視版本更新紀錄",
     "Very weak password" : "密碼安全性極弱",
     "Weak password" : "密碼安全性弱",
     "So-so password" : "密碼安全性普通",
@@ -570,11 +549,6 @@ OC.L10N.register(
     "Installing …" : "正在安裝 …",
     "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 賬號",
     "Currently logged in as %1$s (%2$s)." : "目前以 %1$s (%2$s) 身份登入。",
-    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳戶",
-    "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
-    "The following apps will be updated:" : "將更新以下的 APP：",
-    "The theme %s has been disabled." : "主題 %s 已經被停用。",
-    "Detailed logs" : "詳細記錄檔",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>"
+    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳戶"
 },
 "nplurals=1; plural=0;");
