@@ -11,7 +11,7 @@ OC.L10N.register(
     "The page could not be found on the server." : "Die Seite konnte auf dem Server nicht gefunden werden.",
     "%s email verification" : "%s E-Mail-Überprüfung",
     "Email verification" : "E-Mail-Überprüfung",
-    "Click the following button to confirm your email." : "Die folgende Schaltfläche anklicken, um die E-Mail-Adresse zu bestätigen.",
+    "Click the following button to confirm your email." : "Auf die folgende Schaltfläche klicken, um die E-Mail-Adresse zu bestätigen.",
     "Click the following link to confirm your email." : "Auf den nachfolgenden Link klicken, um die E-Mail-Adresse zu bestätigen",
     "Confirm your email" : "Bestätige deine E-Mail-Adresse",
     "Other activities" : "Andere Aktivitäten",
@@ -37,10 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Die folgenden Plattformen werden unterstützt: %s",
     "Server version %s or higher is required." : "Server Version %s oder höher wird benötigt.",
     "Server version %s or lower is required." : "Server Version %s oder niedriger wird benötigt.",
-    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Das angemeldete Konto muss ein Administrator, ein Unteradministrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Das angemeldete Konto muss ein Administrationskonto sein, ein Unteradministrationskontor sein, oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen",
     "Your current IP address doesn't allow you to perform admin actions" : "Unter deiner aktuellen IP-Adresse sind keine Administrationsaktionen erlaubt",
-    "Logged in account must be an admin or sub admin" : "Das angemeldete Konto muss ein (Unter-)Administrator sein",
-    "Logged in account must be an admin" : "Das angemeldete Konto muss ein Administrator sein",
+    "Logged in account must be an admin or sub admin" : "Das angemeldete Konto muss ein (Unter-)Administrationskonto sein",
+    "Logged in account must be an admin" : "Das angemeldete Konto muss ein Administrationskonto sein",
     "Wiping of device %s has started" : "Löschen von Gerät %s wurde gestartet",
     "Wiping of device »%s« has started" : "Löschen von Gerät »%s« wurde gestartet",
     "»%s« started remote wipe" : "»%s« hat das Löschen aus der Ferne gestartet",
@@ -129,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Einstellungen",
     "Log out" : "Abmelden",
     "Accounts" : "Konten",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "%s auf Bluesky anzeigen",
     "Email" : "E-Mail",
     "Mail %s" : "E-Mail %s",
     "Fediverse" : "Fediverse",
@@ -144,7 +146,7 @@ OC.L10N.register(
     "About" : "Über",
     "Display name" : "Anzeigename",
     "Headline" : "Überschrift",
-    "Organisation" : "Organisation",
+    "Organization" : "Organisation",
     "Role" : "Funktion",
     "Pronouns" : "Pronomen",
     "Unknown account" : "Unbekanntes Konto",
@@ -158,7 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Es konnte keine Verbindung zur Oracle-Datenbank hergestellt werden",
     "Oracle Login and/or password not valid" : "Oracle-Anmeldename und/oder -Passwort ungültig",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL-Anmeldename und/oder Passwort ungültig",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X wird nicht unterstützt und %s wird unter dieser Plattform nicht richtig funktionieren. Verwendung auf eigene Gefahr!",
+    "macOS is not supported and %s will not work properly on this platform." : "MacOS wird nicht unterstützt und %s wird auf dieser Plattform nicht richtig funktionieren.",
     "For the best results, please consider using a GNU/Linux server instead." : "Zur Gewährleistung eines optimalen Betriebs sollte stattdessen ein GNU/Linux-Server verwendet werden.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte die open_basedir-Einstellung in der php.ini entfernen oder zu 64-Bit-PHP wechseln.",
@@ -272,7 +274,7 @@ OC.L10N.register(
     "The Login is already being used" : "Dieser Anmeldename wird bereits verwendet",
     "Could not create account" : "Konto konnte nicht erstellt werden",
     "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Nur die folgenden Zeichen sind in einem Anmeldenamen erlaubt: \"a-z\", \"A-Z\", \"0-9\", Leerzeichen und \"_.@-'\"",
-    "A valid Login must be provided" : "Ein gültiger Anmeldename muss eingegeben werden.",
+    "A valid Login must be provided" : "Ein gültiger Anmeldename muss eingegeben werden",
     "Login contains whitespace at the beginning or at the end" : "Anmeldename enthält Leerzeichen am Anfang oder am Ende",
     "Login must not consist of dots only" : "Der Anmeldename darf nicht nur aus Punkten bestehen",
     "Username is too long" : "Benutzername ist zu lang",
@@ -288,24 +290,20 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Schreiben in das \"config\"-Verzeichnis ist nicht möglich.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dies kann zumeist behoben werden, indem dem Webserver Schreibzugriff auf das Konfigurationsverzeichnis eingeräumt wird. Siehe auch %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Oder wenn du lieber möchtest, dass die Datei config.php schreibgeschützt bleiben soll, dann setze die Option \"config_is_read_only\" in der Datei auf true. Siehe %s",
-    "Cannot write into \"apps\" directory." : "Schreiben in das \"apps\"-Verzeichnis ist nicht möglich.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird, oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
     "Cannot create \"data\" directory." : "Kann das \"data\"-Verzeichnis nicht erstellen.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dies kann zumeist behoben werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Berechtigungen können zumeist korrigiert werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s. ",
     "Your data directory is not writable." : "Das Datenverzeichnis ist schreibgeschützt.",
     "Setting locale to %s failed." : "Das Setzen der Spracheeinstellung auf %s ist fehlgeschlagen.",
-    "Please install one of these locales on your system and restart your web server." : "Bitte eine dieser Sprachen auf dem System installieren und den Webserver neu starten.",
+    "Please install one of these locales on your system and restart your web server." : "Bitte eine dieser Sprachen (locales) auf dem System installieren und den Webserver neu starten.",
     "PHP module %s not installed." : "PHP-Modul %s nicht installiert.",
     "Please ask your server administrator to install the module." : "Bitte für die Installation des Moduls die Serveradministration kontaktieren.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-Einstellung \"%s\" ist nicht auf \"%s\" gesetzt.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Eine Änderung dieser Einstellung in der php.ini kann diese Nextcloud wieder lauffähig machen.",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Zum Beheben dieses Problems bitte <code>mbstring.func_overload</code> in der php.ini auf <code>0</code> setzen.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
-    "Please ask your server administrator to restart the web server." : "Bitte die Serveradministration konatktieren und um Neustart des Webservers bitten.",
+    "Please ask your server administrator to restart the web server." : "Bitte die Serveradministration kontaktieren und um Neustart des Webservers bitten.",
     "The required %s config variable is not configured in the config.php file." : "Die erforderliche %s Konfigurationsvariable ist in der config.php nicht konfiguriert.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Die Serveradministration bitten, die Nextcloud-Konfiguration zu überprüfen.",
     "Your data directory is readable by other people." : "Dein Datenverzeichnis kann von anderen Benutzern gelesen werden",
@@ -326,25 +324,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
     "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Speicherplatz. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Damit diese Prüfung ausgeführt werden kann, muß sichergestellt sein, dass der Webserver eine Verbindung zu sich selbst herstellen kann. Daher muss er in der Lage sein, mindestens eine seiner `trusted_domains` oder `overwrite.cli.url` aufzulösen und eine Verbindung zu ihnen herzustellen. Dieser Fehler kann das Ergebnis einer serverseitigen DNS-Nichtübereinstimmung oder einer ausgehenden Firewall-Regel sein.",
+    "Analyze images" : "Bilder analysieren",
+    "Ask a question about the given images." : "Eine Frage zu den gewählten Bildern stellen.",
+    "Images" : "Bilder",
+    "Images to ask a question about" : "Bilder, zu denen eine Frage gestellt werden soll",
+    "Question" : "Frage",
+    "What to ask about the images." : "Was alles zu den Bildern gefragt werden kann.",
+    "Generated response" : "Erzeugte Antwort",
+    "The answer to the question" : "Die Antwort auf die Frage",
+    "Audio chat" : "Audio-Chat",
+    "Voice chat with the assistant" : "Sprachchat mit dem Assistenten",
+    "System prompt" : "Systemaufforderung",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Regeln und Annahmen definieren, die der Assistent während des Gesprächs befolgen soll.",
+    "Chat voice message" : "Chat-Sprachnachricht",
+    "Describe a task that you want the assistant to do or ask a question." : "Eine Aufgabe, die der Assistent erledigen soll, beschreiben, oder eine Frage stellen.",
+    "Chat history" : "Chatverlauf",
+    "The history of chat messages before the current message, starting with a message by the user." : "Chatverlauf vor der aktuellen Nachricht, beginnend mit einer Nachricht des Benutzers.",
+    "Input transcript" : "Eingabetranskript",
+    "Transcription of the audio input" : "Transkription der Audio-Eingabe",
+    "Response voice message" : "Antwort-Sprachnachricht",
+    "The generated voice response as part of the conversation" : "Die erstellte Sprachantwort als Teil des Gesprächs",
+    "Output transcript" : "Ausgabetranskript",
+    "Transcription of the audio output" : "Transkription der Audio-Ausgabe",
     "Transcribe audio" : "Audio transkribieren",
     "Transcribe the things said in an audio" : "Inhalt der Audiodatei transkribieren",
     "Audio input" : "Audioeingang",
     "The audio to transcribe" : "Die Audio-Datei zum Transkribieren",
     "Transcription" : "Transkription",
     "The transcribed text" : "Der transkribierte Text",
-    "Chat with an agent" : "Mit einem Agenten chatten",
-    "Chat message" : "Chatnachricht",
-    "A chat message to send to the agent." : "Eine Chatnachricht, die an den Agenten gesendet wird.",
+    "Chat by voice with an agent" : "Per Stimme mit einem Agenten chatten",
+    "Describe a task that you want the agent to do or ask a question." : "Eine Aufgabe, die der Assistent erledigen soll, beschreiben, oder eine Frage stellen.",
     "Confirmation" : "Bestätigung",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Ob zuvor angeforderte Aktionen bestätigt werden sollen: 0 für Verweigerung und 1 für Bestätigung.",
     "Conversation token" : "Unterhaltungstoken",
     "A token representing the conversation." : "Ein Token, das die Unterhaltung repräsentiert.",
-    "Generated response" : "Erzeugte Antwort",
-    "The response from the chat model." : "Die Antwort des Chat-Modells.",
     "The new conversation token" : "Das neue Unterhaltungstoken",
     "Send this along with the next interaction." : "Dies zusammen mit der nächsten Interaktion senden.",
     "Requested actions by the agent" : "Vom Agenten angeforderte Aktionen",
     "Actions that the agent would like to carry out in JSON format." : "Aktionen, die der Agent durchführen möchte, im JSON-Format.",
+    "Chat with an agent" : "Mit einem Agenten chatten",
+    "Chat message" : "Chatnachricht",
+    "A chat message to send to the agent." : "Eine Chatnachricht, die an den Agenten gesendet wird.",
+    "The response from the chat model." : "Die Antwort des Chat-Modells.",
     "Context write" : "Kontext schreiben",
     "Writes text in a given style based on the provided source material." : "Schreibt Text in einem vorgegebenen Stil auf Basis des bereitgestellten Quellmaterials.",
     "Writing style" : "Schreibstil",
@@ -358,6 +379,12 @@ OC.L10N.register(
     "The text to generate an emoji for" : "Der Text aus dem ein Emoji erstellt werden soll",
     "Generated emoji" : "Erstelltes Emoji",
     "The generated emoji based on the input text" : "Das aus dem eingegebenen Text erstelltes Emoji",
+    "Optical character recognition" : "Texterkennung",
+    "Extract text from files like images or PDFs" : "Text aus Dateien wie Bildern oder PDFs extrahieren",
+    "Input files" : "Eingabedateien",
+    "The files to extract text from" : "Die Dateien, aus denen Text extrahiert werden soll",
+    "Output texts" : "Ausgabetexte",
+    "The texts that were extracted from the files" : "Die Texte, die aus den Dateien extrahiert wurden",
     "Generate image" : "Bild erstellen",
     "Generate an image from a text prompt" : "Bild aus einer Texteingabe erstellen",
     "Prompt" : "Prompt",
@@ -380,13 +407,10 @@ OC.L10N.register(
     "Change the tone of a piece of text." : "Den Ton eines Textes ändern.",
     "Write a text that you want the assistant to rewrite in another tone." : "Schreibe einen Text, den der Assistent in einen anderen Ton umschreiben soll.",
     "Desired tone" : "Gewünschter Ton",
-    "In which tone should your text be rewritten?" : "In welchem Ton soll Dein Text umgeschrieben werden?",
+    "In which tone should your text be rewritten?" : "In welchen Ton soll Dein Text umgeschrieben werden?",
     "The rewritten text in the desired tone, written by the assistant:" : "Der umgeschriebene Text im gewünschten Ton, erstellt vom Assistenten:",
     "Chat" : "Chat",
     "Chat with the assistant" : "Mit dem Assistenten chatten",
-    "System prompt" : "Systemaufforderung",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Regeln und Annahmen definieren, die der Assistent während des Gesprächs befolgen soll.",
-    "Chat history" : "Chatverlauf",
     "The history of chat messages before the current message, starting with a message by the user" : "Chatverlauf vor der aktuellen Nachricht, beginnend mit einer Nachricht des Benutzers",
     "Response message" : "Antwortnachricht",
     "The generated response as part of the conversation" : "Die erstellte Antwort als Teil der Unterhaltung",
@@ -450,8 +474,12 @@ OC.L10N.register(
     "Generate headline" : "Überschrift erzeugen",
     "Summarizes text by reducing its length without losing key information." : "Fasst Text zusammen, indem die Länge reduziert wird, ohne dass wichtige Informationen verloren gehen.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrahiert Themen aus einem Text und gibt sie durch Kommas getrennt aus.",
-    "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte versuche es später noch einmal",
-    "Cannot download file" : "Datei kann nicht heruntergeladen werden.",
-    "Login is too long" : "Die Anmeldung dauert zu lange"
+    "Organisation" : "Organisation",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X wird nicht unterstützt und %s wird unter dieser Plattform nicht richtig funktionieren. Verwendung auf eigene Gefahr!",
+    "Login is too long" : "Die Anmeldung dauert zu lange",
+    "Cannot write into \"apps\" directory." : "Schreiben in das \"apps\"-Verzeichnis ist nicht möglich.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird, oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Zum Beheben dieses Problems bitte <code>mbstring.func_overload</code> in der php.ini auf <code>0</code> setzen."
 },
 "nplurals=2; plural=(n != 1);");
